Tutorial
========

.. note:: This tutorial is currently under construction!

    * March 2-6: testing period
    * March 9: ready for use!

.. admonition:: Testers 

    We currently only want you to work thru sections 1-4. Thanks!

.. admonition:: Estimated time

    * 3 hours

Grab your laptop and coffee, and dive into this 7-module tutorial to become a Merlin expert.

..    :doc:`0. Prerequisites<prereqs>`

.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Before you come:

   modules/before

.. toctree::
   :maxdepth: 1
   :numbered:
   :caption: Tutorial modules:

   modules/introduction
   modules/installation
   modules/hello_world/hello_world
   modules/run_simulation/run_simulation
   modules/advanced_topics
   modules/contribute
   modules/port_your_application


